@@ -34,9 +34,10 @@
 #'   treatment effects indicate a beneficial (\code{"good"}) or
 #'   harmful (\code{"bad"}) effect, can be abbreviated; see
 #'   \code{\link{netrank}}.
-#' @param digits.Pscore Minimal number of significant digits for
-#'   P-score, see \code{\link{print.default}} and
-#'   \code{\link{netrank}}.
+#' @param nsim Number of simulations to calculate SUCRAs.
+#' @param digits.prop Minimal number of significant digits for
+#'   P-scores, SUCRAs and direct evidence proportions, see
+#'   \code{\link{print.default}} and \code{\link{netrank}}.
 #' @param smlab A label printed at top of figure. By default, text
 #'   indicating either fixed effect or random effects model is
 #'   printed.
@@ -70,12 +71,13 @@
 #' to provide either \code{sortvar = Pscore}, \code{sortvar =
 #' "Pscore"}, \code{sortvar = -Pscore}, or \code{sortvar = "-Pscore"}
 #' in order to sort treatments according to the ranking generated by
-#' \code{\link{netrank}} which is called internally.  Similar
-#' expressions are possible to sort by treatment comparisons
-#' (\code{sortvar = TE}, etc.), standard error (\code{sortvar =
-#' seTE}), number of studies with direct treatment comparisons
-#' (\code{sortvar = k}), and direct evidence proportion (\code{sortvar
-#' = prop.direct}, see also \code{\link{netmeasures}}).
+#' \code{\link{netrank}} which is called internally. It is also
+#' possible to use "SUCRA" instead of "Pscore". Similar expressions
+#' are possible to sort by treatment comparisons (\code{sortvar = TE},
+#' etc.), standard error (\code{sortvar = seTE}), number of studies
+#' with direct treatment comparisons (\code{sortvar = k}), and direct
+#' evidence proportion (\code{sortvar = prop.direct}, see also
+#' \code{\link{netmeasures}}).
 #'
 #' The arguments \code{leftcols} and \code{rightcols} can be used to
 #' specify columns which are plotted on the left and right side of the
@@ -87,6 +89,7 @@
 #'   effects model) \cr
 #' \code{"seTE"} \tab Corresponding standard errors \cr
 #' \code{"Pscore"} \tab P-scores (see \code{\link{netrank}}) \cr
+#' \code{"SUCRA"} \tab SUCRAs (see \code{\link{netrank}}) \cr
 #' \code{"k"} \tab Number of studies in pairwise comparisons \cr
 #' \code{"prop.direct"} \tab Direct evidence proportions (see
 #'   \code{\link{netmeasures}}) \cr
@@ -189,7 +192,8 @@ forest.netmeta <- function(x,
                            rightlabs,
                            digits = gs("digits.forest"),
                            small.values = x$small.values,
-                           digits.Pscore = 2,
+                           nsim = 1000,
+                           digits.prop = 2,
                            smlab = NULL,
                            sortvar = x$seq,
                            backtransf = x$backtransf,
@@ -221,11 +225,13 @@ forest.netmeta <- function(x,
   chklogical(equal.size)
   ##
   meta:::chknumeric(digits, min = 0, length = 1)
+  ##
   if (is.null(small.values))
     small.values <- "good"
   else
     small.values <- meta:::setchar(small.values, c("good", "bad"))
-  meta:::chknumeric(digits.Pscore, min = 0, length = 1)
+  meta:::chknumeric(nsim, min = 1, length = 1)
+  meta:::chknumeric(digits.prop, min = 0, length = 1)
   ##
   chklogical(baseline.reference)
   ##
@@ -285,17 +291,31 @@ forest.netmeta <- function(x,
   for (i in names(list(...))) {
     if (!is.null(meta:::setchar(i, "weight.study", stop = FALSE)))
       stop("Argument 'weight.study' set internally.", call. = TRUE)
+    if (!is.null(meta:::setchar(i, "prediction", stop = FALSE)))
+      stop("For prediction intervals see example in help file of ",
+           "forest.netsplit().", call. = TRUE)
   }
   
   
   ##
   ##
   ## (2) Extract results for fixed effect and random effects model
-  ##     and calculate P-scores
+  ##     and calculate P-scores and SUCRAs if calcSUCRA == TRUE
   ##
   ##
   one.rg <- length(reference.group) == 1
   ##
+  sortvar.c <- deparse(substitute(sortvar))
+  sortvar.c <- gsub("\"", "", sortvar.c)
+  ##
+  calcPscore <-
+    anyCol(rightcols, "Pscore") || anyCol(leftcols, "Pscore") ||
+    any(matchVar(sortvar.c, "Pscore")) || any(matchVar(sortvar.c, "-Pscore"))
+  ##
+  calcSUCRA <-
+    anyCol(rightcols, "SUCRA") || anyCol(leftcols, "SUCRA") ||
+    any(matchVar(sortvar.c, "SUCRA")) || any(matchVar(sortvar.c, "-SUCRA"))
+  ##
   if (one.rg) {
     if (reference.group == "") {
       warning("First treatment used as reference as argument ",
@@ -318,7 +338,15 @@ forest.netmeta <- function(x,
     ##
     prop.direct <- x$P.fixed
     ##
-    Pscore <- netrank(x, small.values = small.values)$Pscore.fixed
+    if (calcPscore)
+      Pscore <- netrank(x, small.values = small.values,
+                        method = "P-score")$ranking.fixed
+    if (calcSUCRA) {
+      x$comb.fixed <- TRUE
+      x$comb.random <- FALSE
+      SUCRA <- netrank(x, small.values = small.values,
+                       method = "SUCRA", nsim = nsim)$ranking.fixed
+    }
     ##
     text.pooled <- "Fixed Effect Model"
     ##
@@ -334,7 +362,16 @@ forest.netmeta <- function(x,
     ##
     prop.direct <- x$P.random
     ##
-    Pscore <- netrank(x, small.values = small.values)$Pscore.random
+    ##
+    if (calcPscore)
+      Pscore <- netrank(x, small.values = small.values,
+                        method = "P-score")$ranking.random
+    if (calcSUCRA) {
+      x$comb.fixed <- FALSE
+      x$comb.random <- TRUE
+      SUCRA <- netrank(x, small.values = small.values,
+                       method = "SUCRA", nsim = nsim)$ranking.random
+    }
     ##
     text.pooled <- "Random Effects Model"
   }
@@ -357,28 +394,31 @@ forest.netmeta <- function(x,
       smlab  <- text.pooled
   }
   ##
-  rightcols <- setCol(rightcols, rightlabs, "Pscore")
+  rightcols <- setCol(rightcols, "Pscore")
   rightlabs <- setLab(rightlabs, rightcols, "Pscore", "P-score")
   ##
-  rightcols <- setCol(rightcols, rightlabs, "k")
+  rightcols <- setCol(rightcols, "SUCRA")
+  rightlabs <- setLab(rightlabs, rightcols, "SUCRA", "SUCRA")
+  ##
+  rightcols <- setCol(rightcols, "k")
   rightlabs <- setLab(rightlabs, rightcols, "k", "Direct\nComparisons")
   ##
-  rightcols <- setCol(rightcols, rightlabs, "prop.direct")
+  rightcols <- setCol(rightcols, "prop.direct")
   rightlabs <- setLab(rightlabs, rightcols, "prop.direct",
                       "Direct Evidence\nProportion")
   ##
-  leftcols <- setCol(leftcols, leftlabs, "Pscore")
+  leftcols <- setCol(leftcols, "Pscore")
   leftlabs <- setLab(leftlabs, leftcols, "Pscore", "P-score")
   ##
-  leftcols <- setCol(leftcols, leftlabs, "k")
+  leftcols <- setCol(leftcols, "SUCRA")
+  leftlabs <- setLab(leftlabs, leftcols, "SUCRA", "SUCRA")
+  ##
+  leftcols <- setCol(leftcols, "k")
   leftlabs <- setLab(leftlabs, leftcols, "k", "Direct\nComparisons")
   ##
-  leftcols <- setCol(leftcols, leftlabs, "prop.direct")
+  leftcols <- setCol(leftcols, "prop.direct")
   leftlabs <- setLab(leftlabs, leftcols, "prop.direct",
                      "Direct Evidence\nProportion")
-  ##
-  sortvar.c <- deparse(substitute(sortvar))
-  sortvar.c <- gsub("\"", "", sortvar.c)
   
   
   ##
@@ -390,6 +430,7 @@ forest.netmeta <- function(x,
                     treat = character(0),
                     TE = numeric(0), seTE = numeric(0),
                     Pscore = numeric(0),
+                    SUCRA = numeric(0),
                     k = numeric(0),
                     prop.direct = numeric(0),
                     stringsAsFactors = FALSE)
@@ -403,7 +444,8 @@ forest.netmeta <- function(x,
                           labels = labels,
                           TE = TE[, colnames(TE) == rg.i],
                           seTE = seTE[, colnames(seTE) == rg.i],
-                          Pscore = Pscore,
+                          Pscore = if (calcPscore) Pscore else NA,
+                          SUCRA = if (calcSUCRA) SUCRA else NA,
                           k = x$A.matrix[, colnames(TE) == rg.i],
                           prop.direct =
                             if (is.bin) prop.direct
@@ -411,11 +453,12 @@ forest.netmeta <- function(x,
                           stringsAsFactors = FALSE)
     else
       dat.i <- data.frame(comparison = rg.i,
-                          Pscore = Pscore,
-                          TE = TE[rownames(TE) == rg.i, ],
-                          seTE = seTE[rownames(seTE) == rg.i, ],
                           treat = rownames(TE),
                           labels = labels,
+                          TE = TE[rownames(TE) == rg.i, ],
+                          seTE = seTE[rownames(seTE) == rg.i, ],
+                          Pscore = if (calcPscore) Pscore else NA,
+                          SUCRA = if (calcSUCRA) SUCRA else NA,
                           k = x$A.matrix[rownames(TE) == rg.i, ],
                           prop.direct =
                             if (is.bin) prop.direct
@@ -444,6 +487,10 @@ forest.netmeta <- function(x,
       sortvar <- Pscore
     else if (any(matchVar(sortvar.c, "-Pscore")))
       sortvar <- -Pscore
+    else if (any(matchVar(sortvar.c, "SUCRA")))
+      sortvar <- SUCRA
+    else if (any(matchVar(sortvar.c, "-SUCRA")))
+      sortvar <- -SUCRA
     else if (any(matchVar(sortvar.c, "TE")))
       sortvar <- dat.i$TE
     else if (any(matchVar(sortvar.c, "-TE")))
@@ -484,12 +531,16 @@ forest.netmeta <- function(x,
   dat.out <- dat
   ##
   if ("Pscore" %in% names(dat))
-    dat$Pscore <- formatN(dat$Pscore, digits = digits.Pscore,
+    dat$Pscore <- formatN(dat$Pscore, digits = digits.prop,
                           text.NA = lab.NA)
   ##
+  if ("SUCRA" %in% names(dat))
+    dat$SUCRA <- formatN(dat$SUCRA, digits = digits.prop,
+                         text.NA = lab.NA)
+  ##
   if ("prop.direct" %in% names(dat))
     dat$prop.direct <- formatN(dat$prop.direct,
-                               digits = digits.Pscore, text.NA = lab.NA)
+                               digits = digits.prop, text.NA = lab.NA)
   ##
   rm(TE)
   rm(seTE)
