@@ -216,6 +216,7 @@ funnel.netmeta <- function(x,
   chknumeric <- meta:::chknumeric
   ##
   meta:::chkclass(x, "netmeta")
+  ##
   x <- upgradenetmeta(x)
   ##
   pooled <- meta:::setchar(pooled, c("fixed", "random"))
@@ -239,11 +240,11 @@ funnel.netmeta <- function(x,
   chkchar(text.mm)
   ##
   chkchar(sep.trts)
-  chknumeric(nchar.trts, min = 1, single = TRUE)
+  chknumeric(nchar.trts, min = 1, length = 1)
   ##
   chklogical(backtransf)
   ##
-  chknumeric(digits.pval, min = 1, single = TRUE)
+  chknumeric(digits.pval, min = 1, length = 1)
   
   
   ##
@@ -331,7 +332,9 @@ funnel.netmeta <- function(x,
   ## (4) Calculate necessary data for funnel plot
   ##
   ##
-  m.adj <- metagen(res$TE.adj, res$seTE, studlab = res$studlab, sm = x$sm)
+  m.adj <-
+    suppressWarnings(metagen(res$TE.adj, res$seTE,
+                             studlab = res$studlab, sm = x$sm))
   ##
   n.comps <- length(unique(res$comparison))
   ##
