@@ -11,7 +11,7 @@
 #'   between-study variance \eqn{\tau^2} for a random effects model on
 #'   which the net heat plot will be based.
 #' @param showall A logical indicating whether results should be shown
-#'   for all designs or only a sensible subset, see Details.
+#'   for all designs or only a sensible subset (see Details).
 #' @param nchar.trts A numeric defining the minimum number of
 #'   characters used to create unique treatment names.
 #' @param \dots Additional arguments.
@@ -47,11 +47,15 @@
 #' multi-arm studies are marked by '_' following the treatments of the
 #' design.
 #' 
-#' By default (\code{showall = FALSE}), designs where only one
-#' treatment is involved in other designs of the network or where the
-#' removal of corresponding studies would lead to a splitting of the
-#' network do not contribute to the inconsistency assessment and are
-#' not incorporated into the net heat plot.
+#' Designs where only one treatment is involved in other designs of
+#' the network or where the removal of corresponding studies would
+#' lead to a splitting of the network do not contribute to the
+#' inconsistency assessment. By default (\code{showall = TRUE}), these
+#' designs are not incorporated into the net heat plot. If
+#' \code{showall = FALSE}, additional designs with minimal
+#' contribution to the inconsistency Q statistic are not incorporated
+#' (i.e., designs with \code{abs(Q.inc.design)} \code{<=}
+#' \code{.Machine$double.eps^0.5)}.).
 #' 
 #' In the case of \code{random = TRUE}, the net heat plot is based on
 #' a random effects model generalised for multivariate meta-analysis
@@ -106,7 +110,7 @@
 
 
 netheat <- function(x, random = FALSE, tau.preset = NULL,
-                    showall = FALSE,
+                    showall = TRUE,
                     nchar.trts = x$nchar.trts,
                     ...) {
   
@@ -218,18 +222,6 @@ netheat <- function(x, random = FALSE, tau.preset = NULL,
             call. = FALSE)
     return(invisible(NULL))
   }
-  else if (df.Q.between.designs == 1) {
-    warning("Net heat plot not available because detaching single designs ",
-            "leads to a network without loops.",
-            call. = FALSE)
-    return(invisible(NULL))
-  }
-  else if (df.Q.between.designs > 1 & !any(!is.na(residuals))) {
-    warning("Net heat plot not available because detaching ",
-            "single designs leads to a insufficiently connected network.",
-            call. = FALSE)
-    return(invisible(NULL))
-  }
   ##
   Q.inc.design.typ <- apply(residuals, 2, function(x) t(x) %*% solve(V) * x)
   inc <- matrix(Q.inc.design,
@@ -266,7 +258,16 @@ netheat <- function(x, random = FALSE, tau.preset = NULL,
   dmat <- t1
   d1 <- dist(dmat, method = "manhattan")
   d1 <- d1 + dist(t(dmat), method = "manhattan")
-  h1 <- hclust(d1)
+  ##
+  if (length(d1) > 0)
+    h1 <- hclust(d1)
+  else {
+    warning("Insufficient number of designs ",
+            "(available or selected by the program  specification) ",
+            "for a net heat plot.",
+            call. = FALSE)
+    return(invisible(NULL))
+  }
   ##
   t1 <- t1[h1$order, h1$order]
   
